@@ -8,5 +8,4 @@ class StatsDStopWatchBackendTestCase(TestCase):
         with mock.patch('statsd.Client') as mock_client:
             backend = StatsDStopWatchBackend()
             backend.push('key', 0.01)
-        mock_client._send.assert_called_with(mock.ANY, {'stopwatch.key': '10|ms'})
-
+        mock_client._send.assert_called_once_with(mock.ANY, {'stopwatch.key': '10|ms'})
