@@ -1,6 +1,7 @@
 from django.core.urlresolvers import ResolverMatch
 from django.http import HttpRequest, HttpResponse
 from django.test import TestCase
+from stopwatch import errors
 from stopwatch.keybuilders import RestApiKeyBuilder
 
 
@@ -19,3 +20,7 @@ class RestApiKeyBuilderTestCase(TestCase):
     def test_build(self):
         key = self.keybuilder.build(self.request, self.response)
         self.assertEqual(key, 'namespace.tests.test_keybuilders.func.GET.200')
+
+    def test_build_unresolved(self):
+        delattr(self.request, 'resolver_match')
+        self.assertRaises(errors.KeyBuilderException, self.keybuilder.build, self.request, self.response)
